@@ -2,7 +2,7 @@ from modutils import BaseSession
 
 class ES_Session(BaseSession):
 
-    def __init__(self, host:str='localhost', port:str='9200'):
+    def __init__(self, host:str='elasticsearch', port:str='9200'):
         super().__init__()
         self.host = host
         self.port = port
