@@ -34,7 +34,7 @@ def rest_tracker_task(task_data):
         return serializer.errors
 
 @shared_task()
-def initialize_es(host:str='localhost', port:str='9200'):
+def initialize_es(host:str='elasticsearch', port:str='9200'):
     ELASTIC_SESSION.set_host(host)
     ELASTIC_SESSION.set_port(port)
     print(ELASTIC_SESSION.base_url)
